Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(422)

Unified Diff: ios/web/public/crw_navigation_item_storage.h

Issue 2705293014: Created web::UserAgentType. (Closed)
Patch Set: fix GetLastCommittedWebItem Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/web/public/crw_navigation_item_storage.h
diff --git a/ios/web/public/crw_navigation_item_storage.h b/ios/web/public/crw_navigation_item_storage.h
index 9cc7927f891ef689d21cefdeef932ca7e8921a37..50290e441120af160bab0b84000e7497c664341f 100644
--- a/ios/web/public/crw_navigation_item_storage.h
+++ b/ios/web/public/crw_navigation_item_storage.h
@@ -11,6 +11,7 @@
#include "base/strings/string16.h"
#include "base/time/time.h"
#include "ios/web/public/referrer.h"
+#include "ios/web/public/user_agent.h"
#import "ios/web/public/web_state/page_display_state.h"
#include "url/gurl.h"
@@ -41,8 +42,11 @@ extern NSString* const kNavigationItemStorageHTTPRequestHeadersKey;
// Whether or not to bypass showing the resubmit data confirmation when loading
// a POST request (BOOL).
extern NSString* const kNavigationItemStorageSkipRepostFormConfirmationKey;
-// Should desktop user agent be used (BOOL)?
-extern NSString* const kNavigationItemStorageUseDesktopUserAgentKey;
+// The user agent type (std::string).
+extern NSString* const kNavigationItemStorageUserAgentTypeKey;
+// Should desktop user agent be used (BOOL). Deprecated, used for backward
+// compatibility
+extern NSString* const kNavigationItemStorageUseDesktopUserAgentDeprecatedKey;
Eugene But (OOO till 7-30) 2017/02/25 01:51:52 Do you want to add TODO for deprecating this key?
kkhorimoto 2017/02/27 23:29:04 Done.
} // namespace web
@@ -56,8 +60,7 @@ extern NSString* const kNavigationItemStorageUseDesktopUserAgentKey;
@property(nonatomic, assign) base::string16 title;
@property(nonatomic, assign) web::PageDisplayState displayState;
@property(nonatomic, assign) BOOL shouldSkipRepostFormConfirmation;
-@property(nonatomic, assign, getter=isOverridingUserAgent)
- BOOL overridingUserAgent;
+@property(nonatomic, assign) web::UserAgentType userAgentType;
@property(nonatomic, copy) NSData* POSTData;
@property(nonatomic, copy) NSDictionary* HTTPRequestHeaders;

Powered by Google App Engine
This is Rietveld 408576698